@@ -1,33 +1,30 @@
-import logging
+from typing import List
 
 import numpy as np
 import pandas as pd
-
 from scipy.integrate import simps
 
 from ...pipeline import Preprocessor
 
-from typing import List
-
 
 class Mean(Preprocessor):
     def run(self, data: List[pd.DataFrame], **kwargs) -> List[pd.DataFrame]:
-        return [d.mean().to_frame(name='Mean').drop('time') for d in data]
+        return [d.mean().to_frame(name='Mean') for d in data]
 
 
 class Variance(Preprocessor):
     def run(self, data: List[pd.DataFrame], **kwargs) -> List[pd.DataFrame]:
-        return [d.var().to_frame(name='Variance').drop('time') for d in data]
+        return [d.var().to_frame(name='Variance') for d in data]
 
 
 class Skewness(Preprocessor):
     def run(self, data: List[pd.DataFrame], **kwargs) -> List[pd.DataFrame]:
-        return [d.skew().to_frame(name='Skewness').drop('time') for d in data]
+        return [d.skew().to_frame(name='Skewness') for d in data]
 
 
 class Kurtosis(Preprocessor):
     def run(self, data: List[pd.DataFrame], **kwargs) -> List[pd.DataFrame]:
-        return [d.kurt().to_frame(name='Kurtosis').drop('time') for d in data]
+        return [d.kurt().to_frame(name='Kurtosis') for d in data]
 
 
 class ZeroCrossing(Preprocessor):
@@ -37,7 +34,7 @@ class ZeroCrossing(Preprocessor):
             return np.where(np.diff(np.sign(array)))[0].shape[0]
 
         return [
-            d.apply(zero_crossing, raw=True).to_frame(name='Zero Crossing').drop('time')
+            d.apply(zero_crossing, raw=True).to_frame(name='Zero Crossing')
             for d in data
         ]
 
@@ -49,7 +46,7 @@ class AbsoluteArea(Preprocessor):
             return simps(np.abs(array), dx=1e-6)
 
         return [
-            d.apply(absolute_area, raw=True).to_frame(name='Absolute Area').drop('time')
+            d.apply(absolute_area, raw=True).to_frame(name='Absolute Area')
             for d in data
         ]
 
@@ -61,6 +58,6 @@ class PeakToPeak(Preprocessor):
             return np.max(array) - np.min(array)
 
         return [
-            d.apply(pk2pk, raw=True).to_frame(name='Peak To Peak').drop('time')
+            d.apply(pk2pk, raw=True).to_frame(name='Peak To Peak')
             for d in data
         ]
