@@ -1,13 +1,14 @@
-import logging
 import json
+import logging
+
+from typing import List
 
 import numpy as np
 import pandas as pd
 
-from ...io import Raw
-from ...pipeline import Preprocessor
+from mne.io import Raw
 
-from typing import List
+from ...pipeline import Preprocessor
 
 
 class ToDataframe(Preprocessor):
@@ -17,7 +18,7 @@ class ToDataframe(Preprocessor):
         logging.debug('Create DataFrame converter preprocessor')
 
     def run(self, data: Raw, **kwargs) -> pd.DataFrame:
-        dataframe = data.open().to_data_frame()
+        dataframe = data.to_data_frame().drop('time', axis=1)
         return dataframe
 
 
@@ -38,30 +39,10 @@ class ToNumpy(Preprocessor):
         return out
 
     def run(self, data: List[pd.DataFrame], **kwargs) -> List[np.ndarray]:
-        data = [d.to_numpy(dtype=self.dtype) for d in data]
+        data = np.array([d.to_numpy(dtype=self.dtype) for d in data])
         return data
 
 
-class ToNumpy1D(Preprocessor):
-
-    def __init__(self, dtype: str = 'float32') -> None:
-        super().__init__()
-        logging.debug('Create Numpy 1D (%s) converter preprocessor', dtype)
-        self.dtype = dtype
-
-    def to_json(self) -> str:
-        out = {
-            self.__class__.__name__: {
-                'dtype': self.dtype
-            }
-        }
-        out = json.dumps(out)
-        return out
-
-    def run(self, data: List[pd.DataFrame], **kwargs) -> List[np.ndarray]:
-        return [d.to_numpy(dtype=self.dtype).flatten() for d in data]
-
-
 class ToMergedDataframes(Preprocessor):
     def run(self, data: List[List[pd.DataFrame]], **kwargs) -> List[pd.DataFrame]:
         return [pd.concat([d[i].T for d in data]).T for i, _ in enumerate(data[0])]
